mod cholesky;
mod generalized_eigenvalues;
mod lu;
mod qr;
mod qz;
mod real_eigensystem;
mod schur;
mod svd;
mod symmetric_eigen;
